#include <stdio.h>
#include <iostream>
#include <SketchUpAPI/common.h>
#include <SketchUpAPI/geometry.h>
#include <SketchUpAPI/initialize.h>
#include <SketchUpAPI/model/model.h>
#include <SketchUpAPI/model/entities.h>
#include <SketchUpAPI/model/face.h>
#include <SketchUpAPI/model/edge.h>
#include <SketchUpAPI/model/vertex.h>

int main() {
  // Always initialize the API before using it
  SUInitialize();
  // Create an empty model
  SUModelRef model = SU_INVALID;
  SUResult res = SUModelCreate(&model);
  // It's best to always check the return code from each SU function call.
  // Only showing this check once to keep this example short.
  if (res != SU_ERROR_NONE)
    return 1;
  // Get the entity container of the model
  SUEntitiesRef entities = SU_INVALID;
  SUModelGetEntities(model, &entities);
  // Create a loop input describing the vertex ordering for a face's outer loop
  SULoopInputRef outer_loop = SU_INVALID;
  SULoopInputCreate(&outer_loop);
  for (size_t i = 0; i < 3; ++i) {
    SULoopInputAddVertexIndex(outer_loop, i);
  }
  // Create the face
  SUFaceRef face = SU_INVALID;
  SUPoint3D vertices[3] = { { 0.00970228, -0.0209955, -0.00929844 },
                            { 0.0097852, -0.0209685, -0.00929844 },
                            { 0.00983242 -0.0209524 -0.00916564 } };

  //SUPoint3D vertices[3] = { { 0.00970228*100, -0.0209955*100, -0.00929844*100},
  //                        { 0.0097852*100, -0.0209685*100, -0.00929844*100},
  //                        { 0.00983242*100, - 0.0209524*100, -0.00916564*100} };

  SUFaceCreate(&face, vertices, &outer_loop);
  // Add the face to the entities
  SUEntitiesAddFaces(entities, 1, &face);
  // Save the in-memory model to a file
  res = SUModelSaveToFile(model, "new_model.skp");
  //res = SUModelSaveToFileWithVersion(model, "new_model.skp", SUModelVersion_SU2016);
  // Must release the model or there will be memory leaks
  SUModelRelease(&model);
  // Always terminate the API when done using it
  SUTerminate();

  if (res != SU_ERROR_NONE) {
    std::cout << "Unable to save document!";
    return 1;
  }
  
  std::cout << "Document saved!";
  return 0;
}
